ArchiveExtractProgressSink

Trait ArchiveExtractProgressSink 

pub trait ArchiveExtractProgressSink {
    // Required method
    fn file_bytes_extracted(&mut self, archive_path: &str, bytes: u64);
}
Receives logical regular-file bytes while the archive reader extracts data.

Callbacks report uncompressed member payload bytes after they are accepted by the destination writer. Each selected file is capped by its authenticated file_data_size.

Required Methods

fn file_bytes_extracted(&mut self, archive_path: &str, bytes: u64)

Reports newly extracted payload bytes for one archive member.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors